/*
 * $Header: /home/barad-dur/vision/forsyth/schenney/sced-0.94/h/RCS/sced.h,v 1.0 1997/05/06 20:42:37 schenney Exp $
 *
 * $Log: sced.h,v $
 * Revision 1.0  1997/05/06 20:42:37  schenney
 * Initial revision
 *
 */
/*
**    ScEd: A Constraint Based Scene Editor.
**    Copyright (C) 1994-1998  Stephen Chenney (schenney@cs.berkeley.edu)
**
**    This program is free software; you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation; either version 2 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program; if not, write to the Free Software
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define PATCHLEVEL 0
/*
**  sced: A Constraint Based Object Scene Editor
**
**  sced.h: Global header file.
**
**  Created: 05/03/94
*/

#include <stdio.h>
#include <stdlib.h>

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xmu/Converters.h>

#include <Vector.h>

#include <config.h>
#include <defs.h>
#include <enum.h>
#include <types.h>
#include <globals.h>
#include <protos.h>
#include <macros.h>

